djangocms-panel
=================

A Bootstrap panel plugin for Django CMS.


Installation
------------

This plugin requires `Django-CMS` 3.0 or higher, and `Django` 1.7 or higher.

* Add ``'djangocms_panel'`` to your ``INSTALLED_APPS`` setting.
* Run ``manage.py migrate djangocms_panel``.


Usage
-----

Just add the `Panel` CMS plugin to any placeholder in your pages. It acts as a
container for other plugins, much like the built-in columns plugin.
